@@ -148,7 +148,7 @@ def use_config_form_distributed_frame_config_module():
         nb_print(f'分布式函数调度框架 读取到\n "{m.__file__}:1" 文件里面的变量作为配置了\n')
         for var_namex, var_valuex in m.__dict__.items():
             if var_namex.isupper():
-                setattr(frame_config, var_namex, var_valuex)
+                setattr(frame_config, var_namex, var_valuex)  # 用用户自定义的配置覆盖框架的默认配置。
     except ModuleNotFoundError:
         nb_print(
             f'''分布式函数调度框架检测到 你的项目根目录 {project_root_path} 和当前文件夹 {current_script_path}  下没有 distributed_frame_config.py 文件，\n\n''')
